==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property audioGroupId
 * @property audioOnlyImage
 * @property audioTrackType
 * @property segmentType
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs(
    public val audioGroupId: Output<String>? = null,
    public val audioOnlyImage:
    Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>? =
        null,
    public val audioTrackType: Output<String>? = null,
    public val segmentType: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.builder()
            .audioGroupId(audioGroupId?.applyValue({ args0 -> args0 }))
            .audioOnlyImage(audioOnlyImage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .audioTrackType(audioTrackType?.applyValue({ args0 -> args0 }))
            .segmentType(segmentType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgsBuilder
internal constructor() {
    private var audioGroupId: Output<String>? = null

    private var audioOnlyImage:
        Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>? =
        null

    private var audioTrackType: Output<String>? = null

    private var segmentType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("loosjgirbrmhgkjf")
    public suspend fun audioGroupId(`value`: Output<String>) {
        this.audioGroupId = value
    }

    /**
     * @param value
     */
    @JvmName("rbgwwqkmivpanvcd")
    public suspend
    fun audioOnlyImage(`value`: Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>) {
        this.audioOnlyImage = value
    }

    /**
     * @param value
     */
    @JvmName("rdkphcvuxwqblsck")
    public suspend fun audioTrackType(`value`: Output<String>) {
        this.audioTrackType = value
    }

    /**
     * @param value
     */
    @JvmName("xbfkwdyhqysknspr")
    public suspend fun segmentType(`value`: Output<String>) {
        this.segmentType = value
    }

    /**
     * @param value
     */
    @JvmName("kkqjqklkmlokmvvu")
    public suspend fun audioGroupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioGroupId = mapped
    }

    /**
     * @param value
     */
    @JvmName("xkdtwdfgbgbirbbp")
    public suspend
    fun audioOnlyImage(`value`: ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioOnlyImage = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ssfcsnhqwfcwddpn")
    public suspend
    fun audioOnlyImage(argument: suspend ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.audioOnlyImage = mapped
    }

    /**
     * @param value
     */
    @JvmName("pwtbjpjmgehgdwye")
    public suspend fun audioTrackType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioTrackType = mapped
    }

    /**
     * @param value
     */
    @JvmName("waifrbqdqpvpjebr")
    public suspend fun segmentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.segmentType = mapped
    }

    internal fun build():
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs(
            audioGroupId = audioGroupId,
            audioOnlyImage = audioOnlyImage,
            audioTrackType = audioTrackType,
            segmentType = segmentType,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property audioGroupId
 * @property audioOnlyImage
 * @property audioTrackType
 * @property segmentType
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs(
    public val audioGroupId: Output<String>? = null,
    public val audioOnlyImage: Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>? =
        null,
    public val audioTrackType: Output<String>? = null,
    public val segmentType: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs.builder()
            .audioGroupId(audioGroupId?.applyValue({ args0 -> args0 }))
            .audioOnlyImage(audioOnlyImage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .audioTrackType(audioTrackType?.applyValue({ args0 -> args0 }))
            .segmentType(segmentType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgsBuilder
internal constructor() {
    private var audioGroupId: Output<String>? = null

    private var audioOnlyImage:
        Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>? =
        null

    private var audioTrackType: Output<String>? = null

    private var segmentType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("gopmtspmrujxmjpv")
    public suspend fun audioGroupId(`value`: Output<String>) {
        this.audioGroupId = value
    }

    /**
     * @param value
     */
    @JvmName("qgcyqnaxrlicvioa")
    public suspend fun audioOnlyImage(`value`: Output<ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs>) {
        this.audioOnlyImage = value
    }

    /**
     * @param value
     */
    @JvmName("imipmkvvfdewifkt")
    public suspend fun audioTrackType(`value`: Output<String>) {
        this.audioTrackType = value
    }

    /**
     * @param value
     */
    @JvmName("dfphlafqeyhcsllj")
    public suspend fun segmentType(`value`: Output<String>) {
        this.segmentType = value
    }

    /**
     * @param value
     */
    @JvmName("xuxeyeexhklvwfjp")
    public suspend fun audioGroupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioGroupId = mapped
    }

    /**
     * @param value
     */
    @JvmName("fcusdxvctgchwkdy")
    public suspend fun audioOnlyImage(`value`: ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioOnlyImage = mapped
    }

    /**
     * @param argument
     */
    @JvmName("dtvtthtkdwfiklxe")
    public suspend fun audioOnlyImage(argument: suspend ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsAudioOnlyImageArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.audioOnlyImage = mapped
    }

    /**
     * @param value
     */
    @JvmName("xjciybahtigvtgdk")
    public suspend fun audioTrackType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioTrackType = mapped
    }

    /**
     * @param value
     */
    @JvmName("irvenciiivefxufm")
    public suspend fun segmentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.segmentType = mapped
    }

    internal fun build(): ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsAudioOnlyHlsSettingsArgs(
            audioGroupId = audioGroupId,
            audioOnlyImage = audioOnlyImage,
            audioTrackType = audioTrackType,
            segmentType = segmentType,
        )
}
